@@ -2,10 +2,10 @@ package Gimp::Constant;
 
 use Exporter 'import';
 use strict qw(vars);
-use vars qw($VERSION);
+our ($VERSION, @EXPORT, @PARAMS, @INXS);
 
 BEGIN {
-   $VERSION = 2.3000_01;
+   $VERSION = "2.31";
 # XS code in Gimp.xs... for now
 #   eval {
 #      require XSLoader;
@@ -17,8 +17,6 @@ BEGIN {
 #   }
 }
 
-use vars qw(@EXPORT @PARAMS @INXS);
-
 my %sub2value;
 
 for my $class (Gimp->enums_get_type_names) {
